abacusai.prediction_input — AbacusAI documentation

# abacusai.prediction_input

## Classes

`PredictionDataset` | Batch Input Datasets
`PredictionFeatureGroup` | Batch Input Feature Group
`AbstractApiClass` |
`PredictionInput` | Batch inputs

## Module Contents

class abacusai.prediction_input.PredictionDataset(client, datasetId=None, datasetType=None, datasetVersion=None, default=None, required=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Batch Input Datasets

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - datasetId (str) – The unique identifier of the dataset

    - datasetType (str) – dataset type

    - datasetVersion (str) – The unique identifier of the dataset version used for predictions

    - default (bool) – If true, this dataset is the default dataset in the model

    - required (bool) – If true, this dataset is required for the batch prediction

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.prediction_input.PredictionFeatureGroup(client, featureGroupId=None, featureGroupVersion=None, datasetType=None, default=None, required=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Batch Input Feature Group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupId (str) – The unique identifier of the feature group

    - featureGroupVersion (str) – The unique identifier of the feature group version used for predictions

    - datasetType (str) – dataset type

    - default (bool) – If true, this feature group is the default feature group in the model

    - required (bool) – If true, this feature group is required for the batch prediction

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.prediction_input.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.prediction_input.PredictionInput(client, featureGroupDatasetIds=None, datasetIdRemap=None, featureGroups={}, datasets={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Batch inputs

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupDatasetIds (list) – The list of dataset IDs to use as input

    - datasetIdRemap (dict) – Replacement datasets to swap as prediction input

    - featureGroups (PredictionFeatureGroup) – List of prediction feature groups

    - datasets (PredictionDataset) – List of prediction datasets

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict